pub enum HostProbeMode {
Off,
Warn,
Require,
}Expand description
Worker startup host-profile probe policy.
Variants
Off
Do not run hosted profile checks.
Warn
Run hosted profile checks and log failures without blocking startup.
Require
Run hosted profile checks and fail worker startup if they fail or are skipped.
Implementations